@@ -173,6 +173,7 @@ sjt.glm <- function(...,
                     exp.coef = TRUE,
                     p.numeric = TRUE,
                     emph.p = TRUE,
+                    p.zero = FALSE,
                     separate.ci.col = TRUE,
                     newline.ci = TRUE,
                     show.ci = TRUE,
@@ -216,12 +217,10 @@ sjt.glm <- function(...,
   # --------------------------------------------------------
   # check p-value-style option
   # --------------------------------------------------------
-  opt <- getOption("p_zero")
-  if (is.null(opt) || opt == FALSE) {
+  if (!p.zero)
     p_zero <- ""
-  } else {
+  else
     p_zero <- "0"
-  }
   # check hyphen for ci-range
   if (is.null(ci.hyphen)) ci.hyphen <- "&nbsp;&ndash;&nbsp;"
   # replace space with protected space in ci-hyphen
@@ -295,7 +294,7 @@ sjt.glm <- function(...,
   # -------------------------------------
   # iterate all models
   # -------------------------------------
-  for (i in 1:length(input_list)) {
+  for (i in seq_len(length(input_list))) {
     # -------------------------------------
     # retrieve model
     # -------------------------------------
@@ -305,7 +304,8 @@ sjt.glm <- function(...,
     # -------------------------------------
     if (lmerob) {
       # get cleaned CI
-      confis <- get_cleaned_ciMerMod(fit, "glm", T)
+      confis <- get_cleaned_ciMerMod(fit, "lm", T) %>% 
+        dplyr::select_("-term")
       coef.fit <- lme4::fixef(fit)
     } else {
       confis <- stats::confint(fit)
@@ -404,7 +404,7 @@ sjt.glm <- function(...,
   # -------------------------------------
   # replace NA, created by join, with empty string
   # -------------------------------------
-  for (i in 1:ncol(joined.df)) {
+  for (i in seq_len(ncol(joined.df))) {
     joined.df[, i] <- sapply(joined.df[, i], function(x) if (is.na(x)) x <- "" else x)
   }
   # -------------------------------------
@@ -417,7 +417,7 @@ sjt.glm <- function(...,
       # if so, retrieve index numbers
       tmp_re <- c()
       # iterate all var names
-      for (re in 1:length(remove.estimates)) {
+      for (re in seq_len(length(remove.estimates))) {
         # find row index by name
         tmp_re <- c(tmp_re, which(joined.df$coef.name == remove.estimates[re]))
       }
@@ -433,7 +433,7 @@ sjt.glm <- function(...,
       message("Intercept cannot be removed from table output. However, you may fake with style sheet, e.g. CSS = list(css.topcontentborder = \"+font-size: 0px;\").")
     }
     # create all row indices
-    rowind <- c(1:nrow(joined.df))
+    rowind <- seq_len(nrow(joined.df))
     # "inverse" removable inices
     keep.estimates <- rowind[-remove.estimates]
     # select rows
@@ -632,7 +632,7 @@ sjt.glm <- function(...,
   # -------------------------------------
   # subsequent rows: pedictors
   # -------------------------------------
-  for (i in 1:(nrow(joined.df) - 1)) {
+  for (i in seq_len(nrow(joined.df) - 1)) {
     # -------------------------------------
     # do we need to insert a "factor grouping headline row"?
     # -------------------------------------
@@ -1209,6 +1209,7 @@ sjt.glmer <- function(...,
                       exp.coef = TRUE,
                       p.numeric = TRUE,
                       emph.p = TRUE,
+                      p.zero = FALSE,
                       separate.ci.col = TRUE,
                       newline.ci = TRUE,
                       show.ci = TRUE,
@@ -1257,7 +1258,7 @@ sjt.glmer <- function(...,
                  string.ci = string.ci, string.se = string.se, string.p = string.p,
                  digits.est = digits.est, digits.p = digits.p, digits.ci = digits.ci,
                  digits.se = digits.se, digits.summary = digits.summary, exp.coef = exp.coef,
-                 p.numeric = p.numeric, emph.p = emph.p,
+                 p.numeric = p.numeric, emph.p = emph.p, p.zero = p.zero,
                  show.ci = show.ci, show.se = show.se,
                  ci.hyphen = ci.hyphen, separate.ci.col = separate.ci.col, newline.ci = newline.ci,
                  group.pred = group.pred, show.col.header = show.col.header, show.r2 = show.r2, show.icc = show.icc,
